=== modified file 'drizzled/locking/global.cc'
--- drizzled/locking/global.cc	2011-01-04 23:23:25 +0000
+++ drizzled/locking/global.cc	2011-01-08 11:27:50 +0000
@@ -1,4 +1,6 @@
-/* Copyright (C) 2000-2006 MySQL AB
+/* 
+    Copyright (C) 2011 Brian Aker
+    Copyright (C) 2000-2006 MySQL AB
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -17,7 +19,9 @@
 /**
   @file
 
-  Locking functions for mysql.
+  @note this is out of date, just for historical reference 
+
+  Locking functions for drizzled.
 
   Because of the new concurrent inserts, we must first get external locks
   before getting internal locks.  If we do it in the other order, the status
@@ -30,7 +34,7 @@
   - For each SQL statement lockTables() is called for all involved
     tables.
     - lockTables() will call
-      table_handler->external_lock(session,locktype) for each table.
+      cursor->external_lock(session,locktype) for each table.
       This is followed by a call to thr_multi_lock() for all tables.
 
   - When statement is done, we call unlockTables().
@@ -122,8 +126,6 @@
                                               lockTables() should
                                               notify upper level and rely
                                               on caller doing this.
-    need_reopen                 Out parameter, TRUE if some tables were altered
-                                or deleted and should be reopened by caller.
 
   RETURN
     A lock structure pointer on success.
@@ -131,8 +133,8 @@
 */
 
 /* Map the return value of thr_lock to an error from errmsg.txt */
-static int thr_lock_errno_to_mysql[]=
-{ 0, 1, ER_LOCK_WAIT_TIMEOUT, ER_LOCK_DEADLOCK };
+static drizzled::error_t thr_lock_errno_to_mysql[]=
+{ EE_OK, EE_ERROR_FIRST, ER_LOCK_WAIT_TIMEOUT, ER_LOCK_DEADLOCK };
 
 
 /**
@@ -163,23 +165,18 @@
   *mysql_lock= 0;
 }
 
-DrizzleLock *Session::lockTables(Table **tables, uint32_t count, uint32_t flags, bool *need_reopen)
+DrizzleLock *Session::lockTables(Table **tables, uint32_t count, uint32_t flags)
 {
   DrizzleLock *sql_lock;
   Table *write_lock_used;
   vector<plugin::StorageEngine *> involved_engines;
-  int rc;
-
-  *need_reopen= false;
-
-  for (;;)
+
+  do
   {
-    if (! (sql_lock= get_lock_data(tables, count, true,
-                                   &write_lock_used)))
+    if (! (sql_lock= get_lock_data(tables, count, true, &write_lock_used)))
       break;
 
-    if (global_read_lock && write_lock_used &&
-        ! (flags & DRIZZLE_LOCK_IGNORE_GLOBAL_READ_LOCK))
+    if (global_read_lock && write_lock_used and (not (flags & DRIZZLE_LOCK_IGNORE_GLOBAL_READ_LOCK)))
     {
       /*
 	Someone has issued LOCK ALL TABLES FOR READ and we want a write lock
@@ -191,11 +188,12 @@
         reset_lock_data_and_free(&sql_lock);
 	break;
       }
+
       if (version != refresh_version)
       {
         /* Clear the lock type of all lock data to avoid reusage. */
         reset_lock_data_and_free(&sql_lock);
-	goto retry;
+	break;
       }
     }
     
@@ -208,12 +206,15 @@
     {
       size_t num_tables= sql_lock->sizeTable();
       plugin::StorageEngine *engine;
-      set<size_t> involved_slots;
+      std::set<size_t> involved_slots;
+
       for (size_t x= 1; x <= num_tables; x++, tables++)
       {
         engine= (*tables)->cursor->getEngine();
+
         if (involved_slots.count(engine->getId()) > 0)
           continue; /* already added to involved engines */
+
         involved_engines.push_back(engine);
         involved_slots.insert(engine->getId());
       }
@@ -241,75 +242,22 @@
     memcpy(sql_lock->getLocks() + sql_lock->sizeLock(),
            sql_lock->getLocks(),
            sql_lock->sizeLock() * sizeof(*sql_lock->getLocks()));
+
     /* Lock on the copied half of the lock data array. */
+    drizzled::error_t rc;
     rc= thr_lock_errno_to_mysql[(int) thr_multi_lock(*this,
                                                      sql_lock->getLocks() +
                                                      sql_lock->sizeLock(),
                                                      sql_lock->sizeLock(),
                                                      this->lock_id)];
-    if (rc > 1)                                 /* a timeout or a deadlock */
+    if (rc)                                 /* a timeout or a deadlock */
     {
       if (sql_lock->sizeTable())
         unlock_external(sql_lock->getTable(), sql_lock->sizeTable());
       reset_lock_data_and_free(&sql_lock);
-      my_error(static_cast<drizzled::error_t>(rc), MYF(0));
-      break;
-    }
-    else if (rc == 1)                           /* aborted */
-    {
-      some_tables_deleted= true;		// Try again
-      sql_lock->setLock(0);                  // Locks are already freed
-      // Fall through: unlock, reset lock data, free and retry
-    }
-    else if (not some_tables_deleted || (flags & DRIZZLE_LOCK_IGNORE_FLUSH))
-    {
-      /*
-        Thread was killed or lock aborted. Let upper level close all
-        used tables and retry or give error.
-      */
-      break;
-    }
-    else if (not open_tables)
-    {
-      // Only using temporary tables, no need to unlock
-      some_tables_deleted= false;
-      break;
-    }
-    set_proc_info(0);
-
-    /* going to retry, unlock all tables */
-    if (sql_lock->sizeLock())
-        sql_lock->unlock(sql_lock->sizeLock());
-
-    if (sql_lock->sizeTable())
-      unlock_external(sql_lock->getTable(), sql_lock->sizeTable());
-
-    /*
-      If thr_multi_lock fails it resets lock type for tables, which
-      were locked before (and including) one that caused error. Lock
-      type for other tables preserved.
-    */
-    reset_lock_data_and_free(&sql_lock);
-
-    /*
-     * Notify all involved engines that the
-     * SQL statement has ended
-     */
-    for_each(involved_engines.begin(),
-             involved_engines.end(),
-             bind2nd(mem_fun(&plugin::StorageEngine::endStatement), this));
-retry:
-    if (flags & DRIZZLE_LOCK_NOTIFY_IF_NEED_REOPEN)
-    {
-      *need_reopen= true;
-      break;
-    }
-
-    if (wait_for_tables(this))
-    {
-      break;					// Couldn't open tables
-    }
-  }
+      my_error(rc, MYF(0));
+    }
+  } while(0);
 
   set_proc_info(0);
   if (getKilled())
@@ -321,7 +269,9 @@
       sql_lock= NULL;
     }
   }
+
   set_time_after_lock();
+
   return (sql_lock);
 }
 

=== modified file 'drizzled/session.cc'
--- drizzled/session.cc	2011-01-05 23:58:29 +0000
+++ drizzled/session.cc	2011-01-08 04:23:10 +0000
@@ -1954,13 +1954,14 @@
 
     if (not lock_tables(tables, counter, &need_reopen))
       break;
+
     if (not need_reopen)
       return true;
+
     close_tables_for_reopen(&tables);
   }
-  if ((handle_derived(lex, &derived_prepare) ||
-       (
-        handle_derived(lex, &derived_filling))))
+
+  if ((handle_derived(lex, &derived_prepare) || (handle_derived(lex, &derived_filling))))
     return true;
 
   return false;

=== modified file 'drizzled/session.h'
--- drizzled/session.h	2011-01-06 23:02:43 +0000
+++ drizzled/session.h	2011-01-08 11:27:50 +0000
@@ -908,7 +908,7 @@
     _global_read_lock= arg;
   }
 
-  DrizzleLock *lockTables(Table **tables, uint32_t count, uint32_t flags, bool *need_reopen);
+  DrizzleLock *lockTables(Table **tables, uint32_t count, uint32_t flags);
   bool lockGlobalReadLock();
   bool lock_table_names(TableList *table_list);
   bool lock_table_names_exclusively(TableList *table_list);

=== modified file 'drizzled/sql_base.cc'
--- drizzled/sql_base.cc	2011-01-04 18:14:33 +0000
+++ drizzled/sql_base.cc	2011-01-08 11:27:50 +0000
@@ -1276,7 +1276,7 @@
 {
   Table *table,*next,**prev;
   Table **tables,**tables_ptr;			// For locks
-  bool error=0, not_used;
+  bool error= false;
   const uint32_t flags= DRIZZLE_LOCK_NOTIFY_IF_NEED_REOPEN |
     DRIZZLE_LOCK_IGNORE_GLOBAL_READ_LOCK |
     DRIZZLE_LOCK_IGNORE_FLUSH;
@@ -1315,6 +1315,7 @@
     error= 1;
   }
   *prev=0;
+
   if (tables != tables_ptr)			// Should we get back old locks
   {
     DrizzleLock *local_lock;
@@ -1325,8 +1326,7 @@
     */
     some_tables_deleted= false;
 
-    if ((local_lock= lockTables(tables, (uint32_t) (tables_ptr - tables),
-                                       flags, &not_used)))
+    if ((local_lock= lockTables(tables, (uint32_t) (tables_ptr - tables), flags)))
     {
       /* unused */
     }
@@ -1437,41 +1437,6 @@
 }
 
 
-/* Wait until all used tables are refreshed */
-
-bool wait_for_tables(Session *session)
-{
-  bool result;
-
-  session->set_proc_info("Waiting for tables");
-  {
-    boost_unique_lock_t lock(table::Cache::singleton().mutex());
-    while (not session->getKilled())
-    {
-      session->some_tables_deleted= false;
-      session->close_old_data_files(false, dropping_tables != 0);
-      if (not table::Cache::singleton().areTablesUsed(session->open_tables, 1))
-      {
-        break;
-      }
-      COND_refresh.wait(lock);
-    }
-    if (session->getKilled())
-      result= true;					// aborted
-    else
-    {
-      /* Now we can open all tables without any interference */
-      session->set_proc_info("Reopen tables");
-      session->version= refresh_version;
-      result= session->reopen_tables(false, false);
-    }
-  }
-  session->set_proc_info(0);
-
-  return result;
-}
-
-
 /*
   drop tables from locked list
 
@@ -1730,9 +1695,7 @@
 
   set_proc_info("Opening table");
   current_tablenr= 0;
-  while (!(table= openTable(table_list, &refresh)) &&
-         refresh)
-    ;
+  while (!(table= openTable(table_list, &refresh)) && refresh) ;
 
   if (table)
   {
@@ -1741,8 +1704,10 @@
 
     assert(lock == 0);	// You must lock everything at once
     if ((table->reginfo.lock_type= lock_type) != TL_UNLOCK)
-      if (! (lock= lockTables(&table_list->table, 1, 0, &refresh)))
-        table= 0;
+    {
+      if (not (lock= lockTables(&table_list->table, 1, 0)))
+        table= NULL;
+    }
   }
 
   set_proc_info(0);
@@ -1798,13 +1763,14 @@
 
   if (!(ptr=start=(Table**) session->alloc(sizeof(Table*)*count)))
     return -1;
+
   for (table= tables; table; table= table->next_global)
   {
     if (!table->placeholder())
       *(ptr++)= table->table;
   }
 
-  if (!(session->lock= session->lockTables(start, (uint32_t) (ptr - start), lock_flag, need_reopen)))
+  if (not (session->lock= session->lockTables(start, (uint32_t) (ptr - start), lock_flag)))
   {
     return -1;
   }

=== modified file 'drizzled/sql_insert.cc'
--- drizzled/sql_insert.cc	2010-12-27 20:04:50 +0000
+++ drizzled/sql_insert.cc	2011-01-08 11:27:50 +0000
@@ -1493,7 +1493,6 @@
   List_iterator_fast<Item> it(*items);
   Item *item;
   Field *tmp_field;
-  bool not_used;
 
   if (not (identifier.isTmp()) && create_table->table->db_stat)
   {
@@ -1639,7 +1638,7 @@
   }
 
   table->reginfo.lock_type=TL_WRITE;
-  if (! ((*lock)= session->lockTables(&table, 1, DRIZZLE_LOCK_IGNORE_FLUSH, &not_used)))
+  if (not ((*lock)= session->lockTables(&table, 1, DRIZZLE_LOCK_IGNORE_FLUSH)))
   {
     if (*lock)
     {

=== modified file 'drizzled/statement/alter_table.cc'
--- drizzled/statement/alter_table.cc	2011-01-08 10:35:13 +0000
+++ drizzled/statement/alter_table.cc	2011-01-08 10:52:13 +0000
@@ -1346,7 +1346,7 @@
            (ulong) (copied + deleted), (ulong) deleted,
            (ulong) session->cuted_fields);
   session->my_ok(copied + deleted, 0, 0L, tmp_name);
-  session->some_tables_deleted= 0;
+  session->some_tables_deleted= false;
 
   return false;
 }

